@@ -47,7 +47,7 @@ sub BUILDARGS {
         my $comment_size = unpack('V', substr($init_content, $offset));
         $offset += 4;
         my ($key, $value) = split /=/, substr($init_content, $offset, $comment_size);
-        $result{comments}{lc $key} = $value;
+        $result{comments}{$key} = $value;
         $offset += $comment_size;
     }
 
@@ -117,12 +117,6 @@ __END__
 
 Audio::Metadata::Flac::Block::Comments - Representation of COMMENTS type block of FLAC metadata.
 
-=head1 VERSION
-
-Version 0.01
-
-=cut
-
 =head1 DESCRIPTION
 
 For internal use only by L<Audio::Metadata::Flac>.
